from setuptools import setup

setup(
    name='rach_pack',
    version='0.4.0',
    description='A sample Python project for rach pack',
    author='Rac',
    author_email='rachitmahajan6399@gmail.com',
    url='https://github.com/r-mhjn/QuizCreator',
    packages=['rach_pack'],
    install_requires=[],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)

